<?php

namespace Superrobota\Announcement\Policies;

use Litepie\User\Contracts\UserPolicy;
use Superrobota\Announcement\Models\Advertisment;

class AdvertismentPolicy
{

    /**
     * Determine if the given user can view the advertisment.
     *
     * @param UserPolicy $user
     * @param Advertisment $advertisment
     *
     * @return bool
     */
    public function view(UserPolicy $user, Advertisment $advertisment)
    {
        if ($user->canDo('announcement.advertisment.view') && $user->isAdmin()) {
            return true;
        }

        return $advertisment->user_id == user_id() && $advertisment->user_type == user_type();
    }

    /**
     * Determine if the given user can create a advertisment.
     *
     * @param UserPolicy $user
     * @param Advertisment $advertisment
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('announcement.advertisment.create');
    }

    /**
     * Determine if the given user can update the given advertisment.
     *
     * @param UserPolicy $user
     * @param Advertisment $advertisment
     *
     * @return bool
     */
    public function update(UserPolicy $user, Advertisment $advertisment)
    {
        if ($user->canDo('announcement.advertisment.edit') && $user->isAdmin()) {
            return true;
        }

        return $advertisment->user_id == user_id() && $advertisment->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given advertisment.
     *
     * @param UserPolicy $user
     * @param Advertisment $advertisment
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Advertisment $advertisment)
    {
        return $advertisment->user_id == user_id() && $advertisment->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given advertisment.
     *
     * @param UserPolicy $user
     * @param Advertisment $advertisment
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Advertisment $advertisment)
    {
        if ($user->canDo('announcement.advertisment.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given advertisment.
     *
     * @param UserPolicy $user
     * @param Advertisment $advertisment
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Advertisment $advertisment)
    {
        if ($user->canDo('announcement.advertisment.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
