<?php

namespace Superrobota\Announcement\Policies;

use Litepie\User\Contracts\UserPolicy;
use Superrobota\Announcement\Models\JobOffert;

class JobOffertPolicy
{

    /**
     * Determine if the given user can view the job_offert.
     *
     * @param UserPolicy $user
     * @param JobOffert $job_offert
     *
     * @return bool
     */
    public function view(UserPolicy $user, JobOffert $job_offert)
    {
        if ($user->canDo('announcement.job_offert.view') && $user->isAdmin()) {
            return true;
        }

        return $job_offert->user_id == user_id() && $job_offert->user_type == user_type();
    }

    /**
     * Determine if the given user can create a job_offert.
     *
     * @param UserPolicy $user
     * @param JobOffert $job_offert
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('announcement.job_offert.create');
    }

    /**
     * Determine if the given user can update the given job_offert.
     *
     * @param UserPolicy $user
     * @param JobOffert $job_offert
     *
     * @return bool
     */
    public function update(UserPolicy $user, JobOffert $job_offert)
    {
        if ($user->canDo('announcement.job_offert.edit') && $user->isAdmin()) {
            return true;
        }

        return $job_offert->user_id == user_id() && $job_offert->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given job_offert.
     *
     * @param UserPolicy $user
     * @param JobOffert $job_offert
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, JobOffert $job_offert)
    {
        return $job_offert->user_id == user_id() && $job_offert->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given job_offert.
     *
     * @param UserPolicy $user
     * @param JobOffert $job_offert
     *
     * @return bool
     */
    public function verify(UserPolicy $user, JobOffert $job_offert)
    {
        if ($user->canDo('announcement.job_offert.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given job_offert.
     *
     * @param UserPolicy $user
     * @param JobOffert $job_offert
     *
     * @return bool
     */
    public function approve(UserPolicy $user, JobOffert $job_offert)
    {
        if ($user->canDo('announcement.job_offert.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
