<?php

namespace Superrobota\Announcement\Policies;

use Litepie\User\Contracts\UserPolicy;
use Superrobota\Announcement\Models\RentalOffer;

class RentalOfferPolicy
{

    /**
     * Determine if the given user can view the rental_offer.
     *
     * @param UserPolicy $user
     * @param RentalOffer $rental_offer
     *
     * @return bool
     */
    public function view(UserPolicy $user, RentalOffer $rental_offer)
    {
        if ($user->canDo('announcement.rental_offer.view') && $user->isAdmin()) {
            return true;
        }

        return $rental_offer->user_id == user_id() && $rental_offer->user_type == user_type();
    }

    /**
     * Determine if the given user can create a rental_offer.
     *
     * @param UserPolicy $user
     * @param RentalOffer $rental_offer
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('announcement.rental_offer.create');
    }

    /**
     * Determine if the given user can update the given rental_offer.
     *
     * @param UserPolicy $user
     * @param RentalOffer $rental_offer
     *
     * @return bool
     */
    public function update(UserPolicy $user, RentalOffer $rental_offer)
    {
        if ($user->canDo('announcement.rental_offer.edit') && $user->isAdmin()) {
            return true;
        }

        return $rental_offer->user_id == user_id() && $rental_offer->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given rental_offer.
     *
     * @param UserPolicy $user
     * @param RentalOffer $rental_offer
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, RentalOffer $rental_offer)
    {
        return $rental_offer->user_id == user_id() && $rental_offer->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given rental_offer.
     *
     * @param UserPolicy $user
     * @param RentalOffer $rental_offer
     *
     * @return bool
     */
    public function verify(UserPolicy $user, RentalOffer $rental_offer)
    {
        if ($user->canDo('announcement.rental_offer.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given rental_offer.
     *
     * @param UserPolicy $user
     * @param RentalOffer $rental_offer
     *
     * @return bool
     */
    public function approve(UserPolicy $user, RentalOffer $rental_offer)
    {
        if ($user->canDo('announcement.rental_offer.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
