<?php

namespace Superrobota\Announcement\Policies;

use Litepie\User\Contracts\UserPolicy;
use Superrobota\Announcement\Models\TrainingOffert;

class TrainingOffertPolicy
{

    /**
     * Determine if the given user can view the training_offert.
     *
     * @param UserPolicy $user
     * @param TrainingOffert $training_offert
     *
     * @return bool
     */
    public function view(UserPolicy $user, TrainingOffert $training_offert)
    {
        if ($user->canDo('announcement.training_offert.view') && $user->isAdmin()) {
            return true;
        }

        return $training_offert->user_id == user_id() && $training_offert->user_type == user_type();
    }

    /**
     * Determine if the given user can create a training_offert.
     *
     * @param UserPolicy $user
     * @param TrainingOffert $training_offert
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('announcement.training_offert.create');
    }

    /**
     * Determine if the given user can update the given training_offert.
     *
     * @param UserPolicy $user
     * @param TrainingOffert $training_offert
     *
     * @return bool
     */
    public function update(UserPolicy $user, TrainingOffert $training_offert)
    {
        if ($user->canDo('announcement.training_offert.edit') && $user->isAdmin()) {
            return true;
        }

        return $training_offert->user_id == user_id() && $training_offert->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given training_offert.
     *
     * @param UserPolicy $user
     * @param TrainingOffert $training_offert
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, TrainingOffert $training_offert)
    {
        return $training_offert->user_id == user_id() && $training_offert->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given training_offert.
     *
     * @param UserPolicy $user
     * @param TrainingOffert $training_offert
     *
     * @return bool
     */
    public function verify(UserPolicy $user, TrainingOffert $training_offert)
    {
        if ($user->canDo('announcement.training_offert.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given training_offert.
     *
     * @param UserPolicy $user
     * @param TrainingOffert $training_offert
     *
     * @return bool
     */
    public function approve(UserPolicy $user, TrainingOffert $training_offert)
    {
        if ($user->canDo('announcement.training_offert.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
