<?php

namespace Superrobota\Announcement\Providers;

use Illuminate\Support\ServiceProvider;

class AnnouncementServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'announcement');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'announcement');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('superrobota.announcement', function ($app) {
            return $this->app->make('Superrobota\Announcement\Announcement');
        });

        // Bind JobOffert to repository
        $this->app->bind(
            'Superrobota\Announcement\Interfaces\JobOffertRepositoryInterface',
            \Superrobota\Announcement\Repositories\Eloquent\JobOffertRepository::class
        );
        // Bind TrainingOffert to repository
        $this->app->bind(
            'Superrobota\Announcement\Interfaces\TrainingOffertRepositoryInterface',
            \Superrobota\Announcement\Repositories\Eloquent\TrainingOffertRepository::class
        );
        // Bind RentalOffer to repository
        $this->app->bind(
            'Superrobota\Announcement\Interfaces\RentalOfferRepositoryInterface',
            \Superrobota\Announcement\Repositories\Eloquent\RentalOfferRepository::class
        );
        // Bind Advertisment to repository
        $this->app->bind(
            'Superrobota\Announcement\Interfaces\AdvertismentRepositoryInterface',
            \Superrobota\Announcement\Repositories\Eloquent\AdvertismentRepository::class
        );

        $this->app->register(\Superrobota\Announcement\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Superrobota\Announcement\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['superrobota.announcement'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('superrobota/announcement.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/announcement')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/announcement')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
