<?php

namespace Superrobota\Announcement\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Illuminate\Routing\Router;
use Superrobota\Announcement\Models\Announcement;
use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'Superrobota\Announcement\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/announcement/job_offert/*')) {
            Route::bind('job_offert', function ($job_offert) {
                $job_offertrepo = $this->app->make('Superrobota\Announcement\Interfaces\JobOffertRepositoryInterface');
                return $job_offertrepo->findorNew($job_offert);
            });
        }

        if (Request::is('*/announcement/training_offert/*')) {
            Route::bind('training_offert', function ($training_offert) {
                $training_offertrepo = $this->app->make('Superrobota\Announcement\Interfaces\TrainingOffertRepositoryInterface');
                return $training_offertrepo->findorNew($training_offert);
            });
        }

        if (Request::is('*/announcement/rental_offer/*')) {
            Route::bind('rental_offer', function ($rental_offer) {
                $rental_offerrepo = $this->app->make('Superrobota\Announcement\Interfaces\RentalOfferRepositoryInterface');
                return $rental_offerrepo->findorNew($rental_offer);
            });
        }

        if (Request::is('*/announcement/advertisment/*')) {
            Route::bind('advertisment', function ($advertisment) {
                $advertismentrepo = $this->app->make('Superrobota\Announcement\Interfaces\AdvertismentRepositoryInterface');
                return $advertismentrepo->findorNew($advertisment);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {
        if (request()->segment(1) == 'api' || request()->segment(2) == 'api') {
            return;
        }
        
        Route::group([
            'middleware' => 'web',
            'namespace'  => $this->namespace,
            'prefix'     => trans_setlocale(),
        ], function ($router) {
            require (__DIR__ . '/../../routes/web.php');
        });
    }

}
